==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1PodSecurityPolicyFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface ExtensionsV1beta1PodSecurityPolicyFluent<A extends ExtensionsV1beta1PodSecurityPolicyFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> withNewMetadata();
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> editMetadata();
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> editOrNewMetadata();
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1PodSecurityPolicySpec getSpec();
    public ExtensionsV1beta1PodSecurityPolicySpec buildSpec();
    public A withSpec(ExtensionsV1beta1PodSecurityPolicySpec spec);
    public Boolean hasSpec();
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> withNewSpec();
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> withNewSpecLike(ExtensionsV1beta1PodSecurityPolicySpec item);
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> editSpec();
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> editOrNewSpec();
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> editOrNewSpecLike(ExtensionsV1beta1PodSecurityPolicySpec item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1PodSecurityPolicySpecFluent<ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1PodSecurityPolicyFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface ExtensionsV1beta1PodSecurityPolicyFluent<A extends ExtensionsV1beta1PodSecurityPolicyFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> withNewMetadata();
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> editMetadata();
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> editOrNewMetadata();
    public ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1PodSecurityPolicySpec getSpec();
    public ExtensionsV1beta1PodSecurityPolicySpec buildSpec();
    public A withSpec(ExtensionsV1beta1PodSecurityPolicySpec spec);
    public Boolean hasSpec();
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> withNewSpec();
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> withNewSpecLike(ExtensionsV1beta1PodSecurityPolicySpec item);
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> editSpec();
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> editOrNewSpec();
    public ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<A> editOrNewSpecLike(ExtensionsV1beta1PodSecurityPolicySpec item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<ExtensionsV1beta1PodSecurityPolicyFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1PodSecurityPolicySpecFluent<ExtensionsV1beta1PodSecurityPolicyFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}
